# nhs-number

Python package to provide utilities for NHS Numbers, including validity checks, normalisation, and generation.

## Package Information

<table>
    <tr>
        <td>License</td>
        <td><img src="https://img.shields.io/pypi/l/nhs-number" alt="Licence type badge"></td>
        <td>Version</td>
        <td><img src="https://img.shields.io/pypi/v/nhs-number" alt="Version badge"></td>
    </tr>
    <tr>
        <td>Supported versions</td>
        <td><img src='https://img.shields.io/pypi/pyversions/nhs-number.svg'></td>
        <td>Coverage</td>
        <td><img src='https://codecov.io/gh/andylaw/NhsNumberChecks/branch/main/graph/badge.svg'></td>
    </tr>
    <tr>
        <td>Wheel</td>
        <td><img src='https://img.shields.io/pypi/wheel/nhs-number'></td>
        <td>Implementation</td>
        <td><img src='https://img.shields.io/pypi/implementation/nhs-number'></td>
    </tr>
    <tr>
        <td>Status</td>
        <td><img src='https://img.shields.io/pypi/status/nhs-number'></td>
        <td>Downloads</td>
        <td><img src='https://img.shields.io/pypi/dm/nhs-number'></td>
    </tr>
</table>

## Documentation

A new and improved documentation site is available at <https://nhs-number.uk-fci.tech>


## Changelog

<https://nhs-number.uk-fci.tech/changelog/>
